/* 
Copyright 2010-2011, Matthew Roberts
This work is licensed under a Creative Commons Attribution 3.0 Unported License.
http://creativecommons.org/licenses/by/3.0/
*/ 

$fn=36;

m3_nut_d = 5.5 + 0.5; m3_nut_h = 2.4 + 0.6;
m4_nut_d = 7 + 0.5; m4_nut_h = 3.2 + 0.3;
m8_nut_d = 13 + 0.5;
low_warp = 0; // tested, and works

include <parametric_involute_gear_v5.0.scad>
include <m_cap.scad>

inf=1000;
eps=0.001;

////////////////

module carriage() {
	translate([0,0,-7]) difference() {
		union() {
			translate([-17,0,0]) cube(size=[97,46,14], center=true);
			translate([-2,0,0]) cube(size=[32,60,14+eps], center=true);
		}
		translate([-17,0,0]) cube(size=[72,25,16], center=true);
		translate([0,-25,0]) cylinder(r=2, h=inf, center=true);
		translate([0,+25,0]) cylinder(r=2, h=inf, center=true);
	}
	translate([-60,-15,0]) rotate([180,0,0]) m4_cap(40);
	translate([-60,0,0]) rotate([180,0,0]) m4_cap(40);
	translate([-60,+15,0]) rotate([180,0,0]) m4_cap(40);
	translate([25,-15,0]) rotate([180,0,0]) m4_cap(40);
	translate([25,0,0]) rotate([180,0,0]) m4_cap(40);
	translate([25,+15,0]) rotate([180,0,0]) m4_cap(40);
}

module motor() { 
	/* FL42STH47-1684A */
	difference() {
		union() {
			translate([0, 0, -47.5/2])
			cube(size=[42.3, 42.3, 47.5], center=true);
			cylinder(r=11, h=4, center=true);
			cylinder(r=2.5, h=48, center=true);
		}
		translate([-15.5, -15.5, 0]) cylinder(r=1.5, h=9, center=true);
		translate([-15.5, +15.5, 0]) cylinder(r=1.5, h=9, center=true);
		translate([+15.5, -15.5, 0]) cylinder(r=1.5, h=9, center=true);
		translate([+15.5, +15.5, 0]) cylinder(r=1.5, h=9, center=true);
	}
}

////////////////

module bearing(id, od, h) {
	difference() {
		cylinder(r=od/2, h=h, center=true);
		cylinder(r=id/2,h=inf, center=true);
	}
}
module bearing_624() { bearing(4,13,5); }
module bearing_MR84() { bearing(4,8,3); }





module feedstock() {
	translate([0,0,25]) cylinder(r=1.5, h=100, center=true);
}

module drive_gear(twist=0) {
	difference() {
		union() {
			translate([0,0,7-eps]) gear(number_of_teeth=9, circular_pitch=270, bore_diameter=0, hub_diameter=0, gear_thickness=12, rim_thickness=12, pressure_angle=15, twist=twist * -360/9 * 12/8);
			translate([0,0,3.5]) cylinder(h = 7, r = 12, center=true);
		}
			
		translate([0,0,3]) rotate([90,180,90]) captive_m3_bolt(inf, 7);
		cylinder(h=inf, r=2.5,center=true);
	}
}

module captive_m3_bolt(l,n) {
	r = 5.5/sqrt(3);
	translate([0,0,l/2]) cylinder(r=1.5, h=l, center=true);
	translate([0,0,n]) { hex(m3_nut_d, m3_nut_h); translate([0,inf/2,0]) cube(size = [r*2,inf,2.5], center=true); }
}

module driven_gear(twist=0) {
	difference() {
		gear(number_of_teeth=31, circular_pitch=270, bore_diameter=4.1, hub_diameter=0, gear_thickness=8, rim_thickness=8, pressure_angle=15, backlash=0.4, twist=twist*360/31);
		rotate([0,0,-5]) {
			translate([0,0,5.5]) {
				hex(m4_nut_d, m4_nut_h);
				rotate([90,0,-120]) captive_m3_bolt(inf, 7);
				rotate([90,0,0]) captive_m3_bolt(inf, 7);
				rotate([90,0,120]) captive_m3_bolt(inf, 7);
			}
			translate([0,0,10]) cylinder(r=m4_nut_d/sqrt(3), h=6, center=true);
			rotate([0,0,-120]) translate([0,13,0]) cylinder(r=6, h=inf, center=true);
			rotate([0,0,0]) translate([0,13,0]) cylinder(r=6, h=inf, center=true);
			rotate([0,0,120]) translate([0,13,0]) cylinder(r=6, h=inf, center=true);
		}
	}
}

module base() {
	difference() {
		translate([-14.8,0,2]) cube(size=[49.6,60,4], center=true);
		translate([-19.8,0,0]) cube(size=[19.6,40,inf], center=true);
		// fillament guide
		cylinder(r=2, h=inf, center=true);
		// mounting holes to carriage
		translate([0,-25,0]) cylinder(r=2, h=inf, center=true);
		translate([0,+25,0]) cylinder(r=2, h=inf, center=true);
		// mounting holes to motor mount
		translate([-34.6,-6,0]) cylinder(r=2, h=inf, center=true);
		// mounting holes to bearing mount
		translate([5.5,10,0]) cylinder(r=1.5, h=inf, center=true);
		translate([5.5,-6,0]) cylinder(r=1.5, h=inf, center=true);
	}
}

module motor_mount() {
	difference() {
		translate([0,0,2.5]) union() {
			cube(size=[44,45,5], center=true);
			translate([44/2-6/2,0,5]) cube(size=[6,10,9], center=true);
			translate([7,45/2-6/2,5]) cube(size=[10,6,9], center=true);
			translate([7-22,45/2-6/2,5]) cube(size=[10,6,9], center=true);  // v2
		}
		// motor holes
		translate([-15.5, -15.5, 0]) cube(size=[3.2, 5+3.2, inf], center=true);
		translate([+15.5, -15.5, 0]) cube(size=[3.2, 5+3.2, inf], center=true);
		//v2: translate([-15.5, +15.5, 0]) cube(size=[3.2, 5+3.2, inf], center=true);
		translate([+15.5, +15.5, 0]) cube(size=[3.2, 5+3.2, inf], center=true);
		for (i = [-2.5:2.5]) {
			translate([0,-i,0]) cylinder(r=12, h=inf, center=true);
		}
		// mounting holes		
		translate([16, 0, 8]) rotate([0, 90, 0]) { cylinder(r=2, h=inf, center=true); hex(m4_nut_d, m4_nut_h); }
		translate([7, 16, 8]) rotate([90, 90, 0]) { cylinder(r=2, h=inf, center=true); hex(m4_nut_d, m4_nut_h); }
		translate([7-22, 16, 8]) rotate([90, 90, 0]) { cylinder(r=2, h=inf, center=true); hex(m4_nut_d, m4_nut_h); } // v2
	}
}

module motor_mount_screws() {
	// motor screws
	translate([0,0,5]) rotate([180, 0, 0]) {
		translate([-15.5, -15.5, 0]) m3_cap(16);
		translate([-15.5, +15.5, 0]) m3_cap(16);
		translate([+15.5, -15.5, 0]) m3_cap(16);
		translate([+15.5, +15.5, 0]) m3_cap(16);
	}

	// mounting screws
	translate([16, 0, 8]) rotate([0, 90, 0]) m4_cap(16);
	translate([7, 16, 8]) rotate([-90, 0, 0]) m4_cap(40);
}


module bearing_mount(axle_d, bearing_d, bearing_w, nut_d) {
	translate([0,0,8.5]) rotate([180,0,0]) 	difference() {
		translate([0, -2.5+1.25-0.5, -2]) cube(size=[44,24+1+1,21], center=true);

		// remove corners to help with warp
		if (low_warp == 1) {
			translate([22, 11.25, 8.5]) rotate([60,45,0]) cube(size=[20,5,20], center=true);
			translate([22, 11.25-25, 8.5]) rotate([-60,45,0]) cube(size=[20,5,20], center=true);
			translate([-22, 11.25, 8.5]) rotate([-60,45,180]) cube(size=[20,5,20], center=true);
			translate([-22, 11.25-25, 8.5]) rotate([60,45,180]) cube(size=[20,5,20], center=true);
		}

		difference() {
			translate([-4, 0, -7]) cube(size=[44,inf,15], center=true);
			translate([16, 0, 0]) cube(size=[20,inf,6], center=true);
			translate([-5-bearing_d/2, 0, 0]) cube(size=[4,inf,6], center=true);
			translate([-21.5+1.5, 0, -2]) cube(size=[5,14,13], center=true);
			translate([20, 0, 2]) rotate([0,45,0]) cube(size=[12,inf+eps,12], center=true);
		}
		translate([-4,0,0]) rotate([90,0,0]) {
			cylinder(r=(axle_d+2)/2, h=inf, center=true);
			translate([0,0,-8]) cylinder(r=bearing_d/2, h=10, center=true);
			translate([0,0,12.5]) cylinder(r=bearing_d/2, h=10, center=true);
		}
		// fillament guide
		translate([0,0,-3.5]) rotate([0,90,0]) cylinder(r=2, h=inf, center=true);
		// mounting hole to motor_mount / idle_mount
		translate([-4, 0, 0]) {
			translate([-11, -6, 0]) cylinder(r=2, h=inf, center=true);
			translate([-11, +6, 0]) cylinder(r=2, h=inf, center=true);
			translate([11, -6, 0]) cylinder(r=2, h=inf, center=true);
			translate([11, +6, 0]) cylinder(r=2, h=inf, center=true);
			translate([-11, -6, 7]) rotate([180,0,0]) hex_cone(m4_nut_d, 7, 45);
			//v2: translate([-11, +6, 7]) hex(m4_nut_d, 7);
			translate([11, -6, 7]) rotate([180,0,0]) hex_cone(m4_nut_d, 7, 45);
		}
		// mounting hole to base
		translate([0,6,-9]) rotate([0,90,0]) cylinder(r=1.5, h=inf, center=true);
		translate([0,-10,-9]) rotate([0,90,0]) cylinder(r=1.5, h=inf, center=true);
	}
}
module bearing_mount_624() { bearing_mount(4, 13.2, 7.5, 6); }
module bearing_mount_MR84() { bearing_mount(4, 8.2, 3, 6); }

module bearing_axle_624() {
	rotate([90,0,0]) translate([-4, 8, 0]) {
		translate([0,0,-16]) m4_cap(40);
		translate([0,0,6.5]) bearing_624();
		translate([0,0,-10.5]) bearing_624();
	}
}

module idle_mount(axle_d, bearing_d, bearing_w, nut_d) {
	difference() {
		translate([0,0,13.5/2]) cube(size=[34,22.5,13.5], center=true);
          // make space for the fillament guide
          translate([17,0,15]) cube(size=[12,inf,10], center=true);
		// make space for the idle axle
		rotate([-90,0,0]) translate([0,-10,0]) {
			// bearing
			cylinder(r=bearing_d/2, h=bearing_w, center=true);
			translate([0,-inf/2,0]) cube([bearing_d,inf,  bearing_w], center=true);
			// axle
			cylinder(r=axle_d/2, h=inf, center=true);
			// nut / cap
			translate([0,0,-10]) hex(nut_d,8);
			translate([0,0,10]) hex(nut_d,8);
		}
		// and mounting holes
		translate([-11, -6, 0]) cylinder(r=2, h=inf, center=true);
		translate([-11, +6, 0]) cylinder(r=2, h=inf, center=true);
		translate([11, -6, 0]) cylinder(r=2, h=inf, center=true);
		translate([11, +6, 0]) cylinder(r=2, h=inf, center=true);
	}
}
module idle_mount_624() { idle_mount(4, 13 + 1, 7.5, m4_nut_d); }

module idle_axle_624() {
	rotate([-90,0,0]) {
		translate([0,-10,0]) bearing_624();
		translate([0,-10,-6.5]) m4_cap(16);
		translate([0,-10,7]) m4_nut();
	}
}







/* generate the assembled extrduer - not 2-manifold, so cannot be exported */
color([0.5, 0.5, 0.5, 0.5]) carriage();
color([0.5, 0.5, 0.5, 1.0]) feedstock();
base();
rotate([90, 90, 0]) translate([-26, -4, 0]) {
	translate([0,-30.6,-2]) {
		motor_mount();
		color([0.5, 0.5, 0.5, 0.5]) motor();
		color([0.5, 0.5, 0.5, 0.5]) motor_mount_screws();
	}
	translate([0,-30.6,0]) drive_gear();
	translate([-4,0,12]) driven_gear();
	rotate([-90, 0, 0]) translate([0,0,-8]) {
		bearing_mount_624();
		color([0.5, 0.5, 0.5, 0.5]) bearing_axle_624();
//		bearing_mount_MR84();
//		color([0.5, 0.5, 0.5, 0.5]) bearing_axle_MR84();
	}
}
translate([17,0, 30]) rotate([0, -90, 0])  {
	idle_mount_624();
	color([0.5, 0.5, 0.5, 0.5]) idle_axle_624();
}


/* uncomment to generate individual parts */
//base();
//bearing_mount_624();
//bearing_mount_MR84(); //untested
//drive_gear();
//driven_gear();
//drive_gear(twist=1); // helical drive gear
//driven_gear(twist=1); // helical driven gear
//idle_mount_624();
//motor_mount();
